<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Shopall Pro
 * @since Shopall Pro 1.0.0
 */

if ( ! function_exists( 'shopall_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Shopall Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function shopall_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'shopall_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'shopall_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Shopall Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function shopall_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'shopall_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'shopall_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Shopall Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function shopall_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'shopall_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'shopall_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Shopall Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function shopall_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[slider_content_type]' )->value();
	return shopall_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[slider_content_type]' )->value();
	return shopall_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[slider_content_type]' )->value();
	return shopall_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if service section is enabled.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is category.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[service_content_type]' )->value();
	return shopall_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[service_content_type]' )->value();
	return shopall_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[service_content_type]' )->value();
	return shopall_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[latest_product_section_enable]' )->value() );
}


/**
 * Check if popular_product section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_popular_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[popular_product_section_enable]' )->value() );
}

/**
 * Check if popular_product section content type is post.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_popular_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[popular_product_content_type]' )->value();
	return shopall_pro_is_popular_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_product section content type is page.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_popular_product_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[popular_product_content_type]' )->value();
	return shopall_pro_is_popular_product_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_product section content type is custom.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_popular_product_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[popular_product_content_type]' )->value();
	return shopall_pro_is_popular_product_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if product_collection section is enabled.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_product_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[product_collection_section_enable]' )->value() );
}

/**
 * Check if product_collection section content type is category.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_product_collection_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[product_collection_content_type]' )->value();
	return shopall_pro_is_product_collection_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if product_collection section content type is page.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_product_collection_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[product_collection_content_type]' )->value();
	return shopall_pro_is_product_collection_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if product_collection section content type is post.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_product_collection_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[product_collection_content_type]' )->value();
	return shopall_pro_is_product_collection_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_product section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[recent_product_section_enable]' )->value() );
}

function shopall_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[recent_product_content_type]' )->value();
	return shopall_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

function shopall_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[recent_product_content_type]' )->value();
	return shopall_pro_is_recent_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if featured_product section is enabled.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[featured_product_section_enable]' )->value() );
}

/**
 * Check if featured_product section content type is category.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_featured_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[featured_product_content_type]' )->value();
	return shopall_pro_is_featured_product_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_product section content type is page.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_featured_product_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[featured_product_content_type]' )->value();
	return shopall_pro_is_featured_product_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_product section content type is post.
 *
 * @since shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_featured_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[featured_product_content_type]' )->value();
	return shopall_pro_is_featured_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[trending_product_section_enable]' )->value() );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function shopall_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[trending_content_type_1]' )->value();
	return shopall_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function shopall_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[trending_content_type_2]' )->value();
	return shopall_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function shopall_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[trending_content_type_3]' )->value();
	return shopall_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function shopall_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[trending_content_type_1]' )->value();
	return shopall_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function shopall_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[trending_content_type_2]' )->value();
	return shopall_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function shopall_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[trending_content_type_3]' )->value();
	return shopall_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}





/**
 * Check if counter section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[counter_section_enable]' )->value() );
}

/**
 * Check if partner section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_partner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[partner_section_enable]' )->value() );
}

/**
 * Check if partner section content type is category.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_partner_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[partner_content_type]' )->value();
	return shopall_pro_is_partner_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if partner section content type is page.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_partner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[partner_content_type]' )->value();
	return shopall_pro_is_partner_section_enable( $control ) && ( 'page' == $content_type );
}

/*
 * Check if partner section content type is post.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
 
function shopall_pro_is_partner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[partner_content_type]' )->value();
	return shopall_pro_is_partner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if partner section content type is recent.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_partner_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[partner_content_type]' )->value();
	return shopall_pro_is_partner_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[blog_content_type]' )->value();
	return shopall_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[blog_content_type]' )->value();
	return shopall_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[blog_content_type]' )->value();
	return shopall_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[blog_content_type]' )->value();
	return shopall_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}



/**
 * Check if testimonial section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[testimonial_content_type]' )->value();
	return shopall_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[testimonial_content_type]' )->value();
	return shopall_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[testimonial_content_type]' )->value();
	return shopall_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[testimonial_content_type]' )->value();
	return shopall_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[testimonial_content_type]' )->value();
	return shopall_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type && 'tp-testimonial' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'shopall_pro_theme_options[testimonial_content_type]' )->value();
	return shopall_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Shopall Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function shopall_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'shopall_pro_theme_options[subscription_section_enable]' )->value() );
}